==> bluedevil-2.1.1.tar.xz: bluedevil-2.1.1/src/daemon/kded/filereceiver/obexagent.cpp <==
/*************************************************************************************
 *  Copyright (C) 2013 by Alejandro Fiestas Fiestas <afiestas@kde.org>               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include "obexagent.h"
#include "receivefilejob.h"
#include "../BlueDevilDaemon.h"

#include <QIcon>
#include <QDBusConnection>

#include <kdebug.h>

ObexAgent::ObexAgent(const KComponentData &componentData, QObject* parent)
    : QDBusAbstractAdaptor(parent)
    , m_componentData(componentData)
{
    kDebug(dblue());
    if (!QDBusConnection::sessionBus().registerObject("/BlueDevil_receiveAgent", parent)) {
        kDebug() << "The dbus object can't be registered";
        return;
    }
}

ObexAgent::~ObexAgent()
{

}

QString ObexAgent::AuthorizePush(const QDBusObjectPath& path, const QDBusMessage &msg)
{
    kDebug(dblue());

    msg.setDelayedReply(true);

    ReceiveFileJob *job = new ReceiveFileJob(msg, path.path(), m_componentData, this);
    job->start();

    return QString();
}

void ObexAgent::Cancel()
{
    kDebug(dblue());
}


void ObexAgent::Release()
{
    kDebug(dblue());
}

==> bluedevil-5.1.95.tar.xz: bluedevil-5.1.95/src/daemon/kded/filereceiver/obexagent.cpp <==
/*************************************************************************************
 *  Copyright (C) 2013 by Alejandro Fiestas Fiestas <afiestas@kde.org>               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include "obexagent.h"
#include "receivefilejob.h"
#include "../BlueDevilDaemon.h"

#include <QIcon>
#include <QDebug>
#include <QDBusConnection>

ObexAgent::ObexAgent(QObject* parent)
    : QDBusAbstractAdaptor(parent)
{
    qCDebug(BLUEDAEMON);
    if (!QDBusConnection::sessionBus().registerObject(QStringLiteral("/BlueDevil_receiveAgent"), parent)) {
        qDebug() << "The dbus object can't be registered";
        return;
    }
}

ObexAgent::~ObexAgent()
{

}

QString ObexAgent::AuthorizePush(const QDBusObjectPath& path, const QDBusMessage &msg)
{
    qCDebug(BLUEDAEMON);

    msg.setDelayedReply(true);

    ReceiveFileJob *job = new ReceiveFileJob(msg, path.path(), this);
    job->start();

    return QString();
}

void ObexAgent::Cancel()
{
    qCDebug(BLUEDAEMON);
}


void ObexAgent::Release()
{
    qCDebug(BLUEDAEMON);
}
